/* KallistiOS 1.1.8

   dc/maple/lightgun.h
   (C)2000-2002 Jordan DeLong, Dan Potter

   $Id: lightgun.h,v 1.4 2002/05/24 06:47:26 bardtx Exp $

   Thanks to Marcus Comstedt for information on the lightgun.
*/

#ifndef __DC_MAPLE_LIGHTGUN_H
#define __DC_MAPLE_LIGHTGUN_H

#include <sys/cdefs.h>
__BEGIN_DECLS

#include <arch/types.h>

/* Buttons bitfield are the same as for other controllers (controller.h) */

/* Our more civilized structure. Note that there are some fairly
   significant differences in value interpretations here between
   this struct and the old one: 

   - "buttons" is zero based: a 1-bit means the button is PRESSED.
   - "gunpos" is the raw value as seen in the 'gun position register' this
     is the position at which the controller saw the TV 'beam' and can be
     used to give a more accurate position that gunx/guny. This value is
     always maintained 'as it was seen' and is not modified by the logic in
     KOS.
   - "gunx" and "guny" are all zero based and are attempts at giving
     the current on-screen position (works with 640x480 NTSC at least).
     If the gun is considered to be pointing 'off-screen' these values will
     be set to -1.

   Note also that this is the struct you will get back if you call
   maple_dev_status(), NOT a lightgun_cond_t. */
typedef struct {
	uint32	buttons;		/* Buttons bitfield */
	uint8 rtrig;			  /* right trigger */
	uint8 ltrig;			  /* left trigger */
	uint8 joyx;			    /* joystick X */
	uint8 joyy;			    /* joystick Y */
	uint8 joy2x;			  /* second joystick X */
	uint8 joy2y;			  /* second joystick Y */
  uint32  gunpos;     /* Raw gun position */
  int gunx, guny;     /* Lightgun X/Y positions */
} lightgun_state_t;

/* Init / Shutdown */
int	 lightgun_init();
void	lightgun_shutdown();

__END_DECLS

#endif	/* __DC_MAPLE_LIGHTGUN_H */

